%define glib2_version           2.7.0
%define dbus_version            0.90
%define dbus_glib_version       0.70

%define lib_major 0
%define lib_name %mklibname consolekit %lib_major
%define lib_name_devel %mklibname -d consolekit 

%define pkgname ConsoleKit2

%define git_url git://anongit.freedesktop.org/ConsoleKit

%define _with_systemd 0

Summary: System daemon for tracking users, sessions and seats
Name: consolekit
Version: 1.2.4
Release: %mkrel 1
License: GPLv2+
Group: System/Libraries
URL: http://www.freedesktop.org/wiki/Software/ConsoleKit
Source0: http://www.freedesktop.org/software/ConsoleKit/dist/%{pkgname}-%{version}.tar.xz
Patch0: ConsoleKit-1.0.2-daemonize_later.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: glib2-devel >= %{glib2_version}
BuildRequires: dbus-devel  >= %{dbus_version}
BuildRequires: dbus-glib-devel >= %{dbus_glib_version}
BuildRequires: polkit-1-devel
BuildRequires: pam-devel
BuildRequires: libx11-devel
BuildRequires: xmlto
BuildRequires: docbook-dtd412-xml
%if %{_with_systemd}
BuildRequires:	systemd-units
%endif

Requires(post): chkconfig
Requires(preun): chkconfig
Provides:   should-restart = system

Provides: %{pkgname} = %{version}-%{release}
Provides: ConsoleKit = %{version}-%{release}
%description 
ConsoleKit2 is a system daemon for tracking what users are logged
into the system and how they interact with the computer (e.g.
which keyboard and mouse they use).

It provides asynchronous notification via the system message bus.

%package x11
Summary: X11-requiring add-ons for ConsoleKit
Group: System/Libraries
Requires: %{name} = %{version}
License: GPLv2+

%description x11
ConsoleKit2 contains some tools that require Xlib to be installed,
those are in this separate package so server systems need not install
X. Applications (such as xorg-x11-xinit) and login managers (such as
gdm) that need to register their X sessions with ConsoleKit needs to
have a Requires: for this package.

%package -n %{lib_name}
Summary: ConsoleKit libraries
Group: System/Libraries
Requires: pam
Requires: %{name} >= %{version}
Provides: %{_lib}%{name} = %{version}-%{release}
License: MIT

%description -n %{lib_name}
Libraries and a PAM module for interacting with ConsoleKit2.

%package -n %{lib_name_devel}
Summary: Development libraries and headers for ConsoleKit2
Group: Development/Libraries
Requires: %{lib_name} = %{version}
Provides: %{name}-devel = %{version}-%{release}
Provides: %{pkgname}-devel = %{version}-%{release}
License: MIT

%description -n %{lib_name_devel}
Headers, libraries and API docs for ConsoleKit2

%prep
%setup -q -n %{pkgname}-%{version}
%apply_patches

%build
./autogen.sh
%configure2_5x --localstatedir=%{_var} \
		--with-pid-file=%{_var}/run/console-kit-daemon.pid \
		--enable-pam-module \
		--with-pam-module-dir=/%{_lib}/security \
%if !%{_with_systemd}
		--without-systemdsystemunitdir \
%endif
		--enable-docbook-docs 

%make

%install
rm -rf $RPM_BUILD_ROOT
%makeinstall_std

rm -f $RPM_BUILD_ROOT%{_libdir}/*.{a,la}
rm -f $RPM_BUILD_ROOT/%{_lib}/security/*.{a,la}
rm -rf $RPM_BUILD_ROOT/%{_datadir}/doc/ConsoleKit
rm -f $RPM_BUILD_ROOT/%{_var}/log/ConsoleKit/history
rm -rf $RPM_BUILD_ROOT/%{_datadir}/gtk-doc

#backward links
mkdir -p %buildroot/usr/lib/ConsoleKit
cp %buildroot/usr/lib64/ConsoleKit/scripts/* %buildroot/usr/lib/ConsoleKit


%clean
rm -rf $RPM_BUILD_ROOT

%pre
# remove obsolete ConsoleKit initscript 
if [ -f %{_sysconfdir}/rc.d/init.d/consolekit ]; then 
    /sbin/service consolekit stop > /dev/null 2>/dev/null || :
    /sbin/chkconfig --del consolekit
fi

%post
if [ -f /var/log/ConsoleKit/history ]; then
    chmod a+r /var/log/ConsoleKit/history
fi

%post -n %{lib_name}
/sbin/ldconfig

%postun -n %{lib_name}
/sbin/ldconfig

%files
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/*
%{_sysconfdir}/X11/xinit/xinitrc.d/90-consolekit
%{_sysconfdir}/logrotate.d/consolekit
%{_sbindir}/console-kit-daemon
%{_sbindir}/ck-log-system-start
%{_sbindir}/ck-log-system-restart
%{_sbindir}/ck-log-system-stop
%{_bindir}/ck-history
%{_bindir}/ck-list-sessions
%{_bindir}/ck-launch-session

/usr/lib/ConsoleKit
%{_libdir}/ConsoleKit

%{_mandir}
%{_docdir}
%{_datadir}/locale
%config(noreplace) %{_sysconfdir}/ConsoleKit
%{_datadir}/polkit-1/actions/*
%{_datadir}/dbus-1/system-services/*
%attr(755,root,root) %{_var}/log/ConsoleKit
%attr(750,root,root) %{_var}/run/ConsoleKit
%if %{_with_systemd}
/lib/systemd
/lib/systemd/system/console-kit-daemon.service
/lib/systemd/system/console-kit-log-system-start.service
/lib/systemd/system/console-kit-log-system-stop.service
/lib/systemd/system/console-kit-log-system-restart.service
/lib/systemd/system/basic.target.wants/console-kit-log-system-start.service
/lib/systemd/system/halt.target.wants/console-kit-log-system-stop.service
/lib/systemd/system/poweroff.target.wants/console-kit-log-system-stop.service
/lib/systemd/system/reboot.target.wants/console-kit-log-system-restart.service
%endif

%files x11
%defattr(-,root,root,-)
%{_libexecdir}/ck-*

%files -n %{lib_name}
%defattr(-,root,root,-)
%{_libdir}/lib*.so.*
/%{_lib}/security/*.so
%{_libdir}/girepository-1.0/libconsolekit-1.0.typelib
%{_datadir}/dbus-1/interfaces/*

%files -n %{lib_name_devel}
%defattr(-,root,root,-)
%doc doc/dbus/ConsoleKit.html
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*
%{_includedir}/*
%{_datadir}/gir-1.0/libconsolekit-1.0.gir

%changelog
* Thu Jul 21 2022 onkelho <oh.quait at gmail.com> - 1.2.4-1pclos2022
- new release

* Sat Aug 10 2019 tex - 1.2.1-3pclos2019
- rebuild against updates

* Sun Aug 12 2018 tex 1.2.1-2pclos2018
- rebuild against updates

* Sun Dec 24 2017 bb2 <bb2> - 1.2.1-1pclos2017
- new version

* Fri Oct 27 2017 bb2 <bb2> - 1.2.0-2pclos2017
- update from unstable git 

* Thu Jul 20 2017 bb2 <bb2> - 1.2.0-1pclos2017
- update

* Wed Mar 15 2017 bb2 <bb2> - 1.0.2-2pclos2017
- apply patch0

* Tue Mar 14 2017 bb2 <bb2> - 1.0.2-1pclos2017
- update to consolekit2 for MATE 1.18.0 

* Fri Apr 24 2014 bb <bb> 0.4.5-2pclos2014
- rebuild openssl

* Sat Jun 25 2011 Texstar <texstar at gmail.com> 0.4.5-1pclos2011
- 0.4.5

* Sun Nov 28 2010 Texstar <texstar at gmail.com> 0.4.3-1pclos2010
- 0.4.3

* Wed May 13 2009 don_crissti <don_crissti@gmx.com> 0.3.0-2pclos2009
- reimport consolekit from mandi

